@@ -31,6 +31,10 @@
 int
 main(int /* argc */, char** /* argv */)
 {
+  // Set the global C and C++ locale to the user-configured locale,
+  // so we can use std::cout with UTF-8, via Glib::ustring, without exceptions.
+  std::locale::global(std::locale(""));
+
   #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
   try
   {
